==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/DataFlowReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.DataFlowReferenceArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.DataFlowReferenceType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Data flow reference type.
 * @property datasetParameters Reference data flow parameters from dataset.
 * @property parameters Data flow parameters
 * @property referenceName Reference data flow name.
 * @property type Data flow reference type.
 */
public data class DataFlowReferenceArgs(
    public val datasetParameters: Output<Any>? = null,
    public val parameters: Output<Map<String, Any>>? = null,
    public val referenceName: Output<String>,
    public val type: Output<Either<String, DataFlowReferenceType>>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.DataFlowReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.DataFlowReferenceArgs =
        com.pulumi.azurenative.datafactory.inputs.DataFlowReferenceArgs.builder()
            .datasetParameters(datasetParameters?.applyValue({ args0 -> args0 }))
            .parameters(
                parameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .referenceName(referenceName.applyValue({ args0 -> args0 }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataFlowReferenceArgs].
 */
@PulumiTagMarker
public class DataFlowReferenceArgsBuilder internal constructor() {
    private var datasetParameters: Output<Any>? = null

    private var parameters: Output<Map<String, Any>>? = null

    private var referenceName: Output<String>? = null

    private var type: Output<Either<String, DataFlowReferenceType>>? = null

    /**
     * @param value Reference data flow parameters from dataset.
     */
    @JvmName("dlptkmfpocemvuln")
    public suspend fun datasetParameters(`value`: Output<Any>) {
        this.datasetParameters = value
    }

    /**
     * @param value Data flow parameters
     */
    @JvmName("xfajexefxsvrcwcf")
    public suspend fun parameters(`value`: Output<Map<String, Any>>) {
        this.parameters = value
    }

    /**
     * @param value Reference data flow name.
     */
    @JvmName("phvclmnhdbciobli")
    public suspend fun referenceName(`value`: Output<String>) {
        this.referenceName = value
    }

    /**
     * @param value Data flow reference type.
     */
    @JvmName("usdpwujwmsthvaci")
    public suspend fun type(`value`: Output<Either<String, DataFlowReferenceType>>) {
        this.type = value
    }

    /**
     * @param value Reference data flow parameters from dataset.
     */
    @JvmName("nqwhtfnjrdylhtmo")
    public suspend fun datasetParameters(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.datasetParameters = mapped
    }

    /**
     * @param value Data flow parameters
     */
    @JvmName("qfdqjknifjqqcrcj")
    public suspend fun parameters(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param values Data flow parameters
     */
    @JvmName("avgbudlgpjpfopob")
    public fun parameters(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param value Reference data flow name.
     */
    @JvmName("rhhoycvfivpsfieg")
    public suspend fun referenceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.referenceName = mapped
    }

    /**
     * @param value Data flow reference type.
     */
    @JvmName("edacvsvvoqfnoqol")
    public suspend fun type(`value`: Either<String, DataFlowReferenceType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Data flow reference type.
     */
    @JvmName("jvlqhcahdtaheufn")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DataFlowReferenceType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Data flow reference type.
     */
    @JvmName("styxubasmmwaviyi")
    public fun type(`value`: DataFlowReferenceType) {
        val toBeMapped = Either.ofRight<String, DataFlowReferenceType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): DataFlowReferenceArgs = DataFlowReferenceArgs(
        datasetParameters = datasetParameters,
        parameters = parameters,
        referenceName = referenceName ?: throw PulumiNullFieldException("referenceName"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/DataFlowReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.DataFlowReferenceArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.DataFlowReferenceType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Data flow reference type.
 * @property datasetParameters Reference data flow parameters from dataset.
 * @property parameters Data flow parameters
 * @property referenceName Reference data flow name.
 * @property type Data flow reference type.
 */
public data class DataFlowReferenceArgs(
    public val datasetParameters: Output<Any>? = null,
    public val parameters: Output<Map<String, Any>>? = null,
    public val referenceName: Output<String>,
    public val type: Output<Either<String, DataFlowReferenceType>>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.DataFlowReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.DataFlowReferenceArgs =
        com.pulumi.azurenative.datafactory.inputs.DataFlowReferenceArgs.builder()
            .datasetParameters(datasetParameters?.applyValue({ args0 -> args0 }))
            .parameters(
                parameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .referenceName(referenceName.applyValue({ args0 -> args0 }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataFlowReferenceArgs].
 */
@PulumiTagMarker
public class DataFlowReferenceArgsBuilder internal constructor() {
    private var datasetParameters: Output<Any>? = null

    private var parameters: Output<Map<String, Any>>? = null

    private var referenceName: Output<String>? = null

    private var type: Output<Either<String, DataFlowReferenceType>>? = null

    /**
     * @param value Reference data flow parameters from dataset.
     */
    @JvmName("yjgxbwdskrmnaavg")
    public suspend fun datasetParameters(`value`: Output<Any>) {
        this.datasetParameters = value
    }

    /**
     * @param value Data flow parameters
     */
    @JvmName("wpbfydqxvgswgcvr")
    public suspend fun parameters(`value`: Output<Map<String, Any>>) {
        this.parameters = value
    }

    /**
     * @param value Reference data flow name.
     */
    @JvmName("xgdupedlkfbdllok")
    public suspend fun referenceName(`value`: Output<String>) {
        this.referenceName = value
    }

    /**
     * @param value Data flow reference type.
     */
    @JvmName("qoncwnsqdbtfuybl")
    public suspend fun type(`value`: Output<Either<String, DataFlowReferenceType>>) {
        this.type = value
    }

    /**
     * @param value Reference data flow parameters from dataset.
     */
    @JvmName("oeytgdndoxpjajwg")
    public suspend fun datasetParameters(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.datasetParameters = mapped
    }

    /**
     * @param value Data flow parameters
     */
    @JvmName("tsxrhdshbcantfjr")
    public suspend fun parameters(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param values Data flow parameters
     */
    @JvmName("cnrknsbvsardyjjf")
    public fun parameters(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param value Reference data flow name.
     */
    @JvmName("aacrovtlvkkoujfs")
    public suspend fun referenceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.referenceName = mapped
    }

    /**
     * @param value Data flow reference type.
     */
    @JvmName("edqehkdiltwpavgn")
    public suspend fun type(`value`: Either<String, DataFlowReferenceType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Data flow reference type.
     */
    @JvmName("bdryjwuxiwimxgio")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DataFlowReferenceType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Data flow reference type.
     */
    @JvmName("nmmikvkmurgfcipe")
    public fun type(`value`: DataFlowReferenceType) {
        val toBeMapped = Either.ofRight<String, DataFlowReferenceType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): DataFlowReferenceArgs = DataFlowReferenceArgs(
        datasetParameters = datasetParameters,
        parameters = parameters,
        referenceName = referenceName ?: throw PulumiNullFieldException("referenceName"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
